@@ -7,7 +7,7 @@ use vars qw($VERSION);
 
 BEGIN
 {
-    $VERSION = '0.25';
+    $VERSION = '0.26';
 
     my $loaded = 0;
     unless ( $ENV{PERL_DATETIME_PP} )
@@ -1151,36 +1151,40 @@ sub delta_md
     my $self = shift;
     my $dt = shift;
 
-    my $dur = $self->subtract_datetime($dt);
+    my ( $smaller, $greater ) = sort $self, $dt;
+
+    my $dur = $greater->subtract_datetime($smaller);
 
     return DateTime::Duration->new( months => $dur->delta_months,
                                     days   => $dur->delta_days );
 }
 
-sub delta_days { DateTime::Duration->new( days => int( $_[0]->jd - $_[1]->jd ) ) }
+sub delta_days
+{
+    my $self = shift;
+    my $dt = shift;
+
+    my ( $smaller, $greater ) = sort $self, $dt;
+
+    DateTime::Duration->new( days => int( $greater->jd - $smaller->jd ) );
+}
 
 sub delta_ms
 {
     my $self = shift;
     my $dt = shift;
 
-    my $days = abs( int( $self->jd - $dt->jd ) );
+    my ( $smaller, $greater ) = sort $self, $dt;
 
-    my $dur = $self->subtract_datetime($dt);
+    my $days = int( $greater->jd - $smaller->jd );
+
+    my $dur = $greater->subtract_datetime($smaller);
 
     my %p;
     $p{hours}   = $dur->hours + ( $days * 24 );
     $p{minutes} = $dur->minutes;
     $p{seconds} = $dur->seconds;
 
-    if ( $self < $dt )
-    {
-        for ( qw( hours minutes seconds ) )
-        {
-            $p{$_} *= -1 if $p{$_};
-        }
-    }
-
     return DateTime::Duration->new(%p);
 }
 
@@ -2903,9 +2907,9 @@ stole all the code from.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 David Rolsky.  All rights reserved.  This program
-is free software; you can redistribute it and/or modify it under the
-same terms as Perl itself.
+Copyright (c) 2003-2005 David Rolsky.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 Portions of the code in this distribution are derived from other
 works.  Please see the CREDITS file for more details.
