@@ -83,7 +83,6 @@ sub initialize {
     # year month day number-of-leapseconds
     #
     _init ( qw(
-1972  Jan. 1  +1 
 1972  Jul. 1  +1
 1973  Jan. 1  +1
 1974  Jan. 1  +1
@@ -143,7 +142,7 @@ system was implemented.
 =item * leap_seconds( $rd )
 
 Returns the number of accumulated leap seconds for a given day,
-in the range 0 .. 23.
+in the range 0 .. 22.
 
 =item * extra_seconds( $rd )
 
@@ -163,9 +162,10 @@ Flvio Soibelmann Glock, E<lt>fglock@pucrs.brE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 Flvio Soibelmann Glock.  All rights reserved.
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+Copyright (c) 2003 Flvio Soibelmann Glock.  Copyright (c) 2004-2005
+David Rolsky.  All rights reserved.  This program is free software;
+you can redistribute it and/or modify it under the same terms as Perl
+itself.
 
 The full text of the license can be found in the LICENSE file included
 with this module.
